=== modified file 'NEWS'
--- NEWS	2005-11-18 06:58:20 +0000
+++ NEWS	2005-11-18 08:01:51 +0000
@@ -63,6 +63,9 @@
     * Show files which are both renamed and modified as such in 'bzr 
       status' output.  (#4503, Daniel Silverstone)
 
+    * Make annotate cope better with revisions committed without a valid 
+      email address.  (Marien Zwart)
+
   TESTING:
 
     * Fix selftest asking for passwords when there are no SFTP keys.  

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2005-11-10 23:01:48 +0000
+++ bzrlib/annotate.py	2005-11-18 08:01:51 +0000
@@ -33,6 +33,7 @@
 
 import bzrlib.weave
 from bzrlib.config import extract_email_address
+from bzrlib.errors import BzrError
 
 
 def annotate_file(branch, rev_id, file_id, verbose=False, full=False,

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2005-11-18 05:45:04 +0000
+++ bzrlib/config.py	2005-11-18 08:01:51 +0000
@@ -133,12 +133,7 @@
 
     def user_email(self):
         """Return just the email component of a username."""
-        e = self.username()
-        m = re.search(r'[\w+.-]+@[\w+.-]+', e)
-        if not m:
-            raise BzrError("%r doesn't seem to contain "
-                           "a reasonable email address" % e)
-        return m.group(0)
+        return extract_email_address(self.username())
 
     def username(self):
         """Return email-style username.
@@ -480,8 +475,8 @@
     """
     m = re.search(r'[\w+.-]+@[\w+.-]+', e)
     if not m:
-        raise BzrError("%r doesn't seem to contain "
-                       "a reasonable email address" % e)
+        raise errors.BzrError("%r doesn't seem to contain "
+                              "a reasonable email address" % e)
     return m.group(0)
 
 class TreeConfig(object):

=== modified file 'bzrlib/selftest/testannotate.py'
--- bzrlib/selftest/testannotate.py	2005-11-07 20:17:57 +0000
+++ bzrlib/selftest/testannotate.py	2005-11-18 08:01:51 +0000
@@ -42,10 +42,13 @@
     def setUp(self):
         super(TestAnnotate, self).setUp()
         b = Branch.initialize('.')
-        self.build_tree_contents([('hello.txt', 'my helicopter\n')])
+        self.build_tree_contents([('hello.txt', 'my helicopter\n'),
+                                  ('nomail.txt', 'nomail\n')])
         b.add(['hello.txt'])
         b.working_tree().commit('add hello', 
                                 committer='test@user')
+        b.add(['nomail.txt'])
+        b.working_tree().commit('add nomail', committer='no mail')
 
     def test_help_annotate(self):
         """Annotate command exists"""
@@ -57,3 +60,10 @@
         self.assertEqualDiff(out, '''\
     1 test@us | my helicopter
 ''')
+
+    def test_no_mail(self):
+        out, err = self.run_bzr_captured(['annotate', 'nomail.txt'])
+        self.assertEquals(err, '')
+        self.assertEqualDiff(out, '''\
+    2 no mail | nomail
+''')

=== modified file 'bzrlib/selftest/testconfig.py'
--- bzrlib/selftest/testconfig.py	2005-11-17 07:45:38 +0000
+++ bzrlib/selftest/testconfig.py	2005-11-18 08:01:51 +0000
@@ -568,3 +568,12 @@
         my_config._get_location_config()._get_parser(branch_file)
         self.assertEqual('bzrlib.selftest.testconfig.post_commit',
                          my_config.post_commit())
+
+
+class TestMailAddressExtraction(TestCase):
+
+    def test_extract_email_address(self):
+        self.assertEqual('jane@test.com',
+                         config.extract_email_address('Jane <jane@test.com>'))
+        self.assertRaises(errors.BzrError,
+                          config.extract_email_address, 'Jane Tester')

